
Changelog
=========

0.0.0
-----

This is a pre-alpha release to experiment with what we can and can't do.

Features
~~~~~~~~

 * New PyYAML Loader subclass for getting ordered maps without ugly !!omap markup
 * Resolves {} markup within YAML nodes
 * Lazily evaluates .copy, .append and .remove instructions
